#![feature(async_closure)]

use config::Config;
use db::Database;
use error::Error;
use tokio::{fs::File, io::AsyncWriteExt};

mod artist;
mod artwork;
mod comment;
pub mod config;
mod db;
mod error;
mod file;
pub mod routes;
mod ructe_poem;

pub type Result<T> = std::result::Result<T, error::Error>;

#[derive(Clone)]
pub struct Critch {
    db: Database,
    config: Config,
}

impl Critch {
    pub async fn new(config: Config) -> Self {
        let db = Database::new(config.database_connection()).await;

        Self { db, config }
    }

    pub async fn save_file(&self, file_name: &str, file_data: Vec<u8>) -> Result<()> {
        let upload_dir = self.config.files_dir();
        if upload_dir.is_dir() {
            let file_handle = upload_dir.join(file_name);
            let mut file = File::create(file_handle).await?;
            file.write_all(&file_data).await?;
            return Ok(());
        } else {
            return Err(Error::UploadDirectory(
                self.config.files_dir().to_string_lossy().to_string(),
            ));
        }
    }
}

include!(concat!(env!("OUT_DIR"), "/templates.rs"));
